#version 450 core

layout(location = 0) out vec4 outColor;

struct VertexOutput {
  vec4 Position;
  vec4 Color;
  vec2 TexCoord;
  vec3 Normal;
};

layout(location = 0) in VertexOutput Input;

layout(set = 1, binding = 0) uniform sampler2D tex;

void main() {
  float DiffusedLightIntensity = 7.0f; // Sets intensity of Diffused Light
  vec3 LightColor = vec3(0.1f, 0.1f, 0.1f); // Sets the color of ambient and diffused light
  vec3 lightPosition = vec3(3, 4, 0); // Sets position of diffused light source

  vec3 norm = normalize(Input.Normal);
  vec3 lightDirection = normalize(lightPosition - Input.Position.xyz);

  float diffusedIntensity = max(dot(norm, lightDirection), 0.0);
  vec3 diffusedLight = diffusedIntensity * (DiffusedLightIntensity*LightColor);
  vec4 diffusedLightAlpha = vec4(diffusedLight, 1.0f); // Sets alpha of diffused light

  vec4 AmbientColor = vec4(LightColor, 1.0f); // Sets alpha of ambient light

  float gamma = 2.2;
  vec4 color = vec4(pow(Input.Color, vec4(gamma))) * (AmbientColor + diffusedLightAlpha) * texture(tex, Input.TexCoord);

  if(color.a < 0.5)
    discard;

  outColor = color;
}
